package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.huiju.estateagents.service.ISysSmsTemplateService;
import com.huiju.estateagents.entity.SysSmsTemplate;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-21
 */

@Api(tags = "")
@RestController
@RequestMapping("/")
public class SysSmsTemplateController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysSmsTemplateController.class);

    @Autowired
    public ISysSmsTemplateService iSysSmsTemplateService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/sysSmsTemplate",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean sysSmsTemplateList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<SysSmsTemplate> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysSmsTemplate> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysSmsTemplate> result = iSysSmsTemplateService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param sysSmsTemplate 实体对象
     * @return
     */
    @RequestMapping(value="/sysSmsTemplate",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean sysSmsTemplateAdd(@ApiParam("保存内容") @RequestBody SysSmsTemplate sysSmsTemplate) throws Exception{

        if (iSysSmsTemplateService.save(sysSmsTemplate)){
            return ResponseBean.success(sysSmsTemplate);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysSmsTemplate/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean sysSmsTemplateDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iSysSmsTemplateService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysSmsTemplate 实体对象
     * @return
     */
    @RequestMapping(value="/sysSmsTemplate/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean sysSmsTemplateUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody SysSmsTemplate sysSmsTemplate) throws Exception{

        if (iSysSmsTemplateService.updateById(sysSmsTemplate)){
            return ResponseBean.success(iSysSmsTemplateService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysSmsTemplate/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean sysSmsTemplateGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iSysSmsTemplateService.getById(id));
    }
}
